context_internal2

Macro context_internal2 

context_internal2!() { /* proc-macro */ }
Available on crate feature _helpers only.
Helper utilities for building procedural macros Macro used by always_context attribute macro

Since it needs to provide the current line by itself